==> Cn_module.4.6.x.tgz: cn_module/4.6.3/install-chuck-norris.php <==
<?php
/* vim: set ts=4 sw=4 sts=4 et: */
/*****************************************************************************\
+-----------------------------------------------------------------------------+
| X-Cart Software license agreement                                           |
| Copyright (c) 2001-2016 Qualiteam software Ltd <info@x-cart.com>            |
| All rights reserved.                                                        |
+-----------------------------------------------------------------------------+
| PLEASE READ  THE FULL TEXT OF SOFTWARE LICENSE AGREEMENT IN THE "COPYRIGHT" |
| FILE PROVIDED WITH THIS DISTRIBUTION. THE AGREEMENT TEXT IS ALSO AVAILABLE  |
| AT THE FOLLOWING URL: http://www.x-cart.com/license.php                     |
|                                                                             |
| THIS AGREEMENT EXPRESSES THE TERMS AND CONDITIONS ON WHICH YOU MAY USE THIS |
| SOFTWARE PROGRAM AND ASSOCIATED DOCUMENTATION THAT QUALITEAM SOFTWARE LTD   |
| (hereinafter referred to as "THE AUTHOR") OF REPUBLIC OF CYPRUS IS          |
| FURNISHING OR MAKING AVAILABLE TO YOU WITH THIS AGREEMENT (COLLECTIVELY,    |
| THE "SOFTWARE"). PLEASE REVIEW THE FOLLOWING TERMS AND CONDITIONS OF THIS   |
| LICENSE AGREEMENT CAREFULLY BEFORE INSTALLING OR USING THE SOFTWARE. BY     |
| INSTALLING, COPYING OR OTHERWISE USING THE SOFTWARE, YOU AND YOUR COMPANY   |
| (COLLECTIVELY, "YOU") ARE ACCEPTING AND AGREEING TO THE TERMS OF THIS       |
| LICENSE AGREEMENT. IF YOU ARE NOT WILLING TO BE BOUND BY THIS AGREEMENT, DO |
| NOT INSTALL OR USE THE SOFTWARE. VARIOUS COPYRIGHTS AND OTHER INTELLECTUAL  |
| PROPERTY RIGHTS PROTECT THE SOFTWARE. THIS AGREEMENT IS A LICENSE AGREEMENT |
| THAT GIVES YOU LIMITED RIGHTS TO USE THE SOFTWARE AND NOT AN AGREEMENT FOR  |
| SALE OR FOR TRANSFER OF TITLE. THE AUTHOR RETAINS ALL RIGHTS NOT EXPRESSLY  |
| GRANTED BY THIS AGREEMENT.                                                  |
+-----------------------------------------------------------------------------+
\*****************************************************************************/

/**
 * Module installation script
 *
 * @category   X-Cart
 * @package    Modules
 * @subpackage Chuck_Norris System
 * @author     Ildar Amankulov
 * @copyright  Copyright (c) 2001-2016 Qualiteam software Ltd <info@x-cart.com>. All rights reserved
 * @license    http://www.x-cart.com/license.php X-Cart license agreement
 * @version    $Id$
 * @link       http://www.x-cart.com/
 * @see        ____file_see____
 */

define('XCART_INSTALL', 1);
    // Only before 4.6.4
define('COMPATIBLE_VERSION', '4.6.x');

define('XMODULE_SERVICE_NAME', 'Chuck_Norris');

$module_definition = array (
    'name'       => 'Chuck_Norris system for X-Cart',
    'script'     => 'install-chuck-norris.php',
    'prefix'     => 'chuck-norris',
    'successmessage' => 'func_success',
    'is_installed'   => 'func_is_installed',
    'onuninstall'    => 'func_cn_onuninstall',
);

if (!@include(dirname(__FILE__).'/top.inc.php')) {
    die('X-Cart not found in ' . dirname(__FILE__));
}

if (
    (file_exists('skin1_original') && !file_exists('skin1'))
) {
    die('You should install X-Cart first');
}

if (!file_exists('skin')) {
    die('Wrong X-Cart version');
}

if (!@include(dirname(__FILE__).'/init.php')) {
    die('init.php not found. Please, unpack ' . $module_definition['name'] . ' module in &lt;xcart&gt; directory');
}

function func_success() {
    global $xcart_package, $module_definition, $xcart_web_dir, $sql_tbl;
?>
<ol>
<li>
<a style="text-decoration: underline; font-weight: bold;" href="<?php echo $xcart_web_dir . DIR_ADMIN; ?>/configuration.php?option=<?php echo XMODULE_SERVICE_NAME;?>"><?php echo_lng('modules_admin_note'); ?></a>
</li>
</ol>
<?php
    db_query("UPDATE $sql_tbl[modules] SET active='Y' WHERE module_name='" . XMODULE_SERVICE_NAME . "'");
    func_data_cache_clear('modules');
}

function func_is_installed() {
    global $xcart_dir;

    // Only before 4.6.4
    require_once $xcart_dir . '/modules/' . XMODULE_SERVICE_NAME . '/install.php';

    return false !== func_query_first_cell('SELECT * FROM xcart_modules WHERE module_name=\'Chuck_Norris\'');
}

function func_cn_onuninstall() {
    global $sql_tbl, $sql_db;

    // Array of new columns added by the module
    // array(table_name => array(columns_names))
    $cn_columns = array(
        'memberships' => array(
            'cn_operator',
        ),
    );

    foreach ($cn_columns as $tbl => $columns) {
        if (isset($sql_tbl[$tbl])) {
            $current_columns = func_query_column("SELECT column_name FROM information_schema.columns WHERE table_schema='$sql_db' and table_name='" . $sql_tbl[$tbl] . "'");
            foreach ($columns as $column) {
                if (in_array($column, $current_columns)) {
                    db_query("ALTER TABLE " . $sql_tbl[$tbl] . " DROP COLUMN `$column`");
                }
            }
        }
    }

    return true;
}

require $xcart_dir . '/include/install.php';

==> Cn_module.4.7.x.tgz: cn_module/4.7.8/install-chuck-norris.php <==
<?php
/* vim: set ts=4 sw=4 sts=4 et: */
/*****************************************************************************\
+-----------------------------------------------------------------------------+
| X-Cart Software license agreement                                           |
| Copyright (c) 2001-present Qualiteam software Ltd <info@x-cart.com>         |
| All rights reserved.                                                        |
+-----------------------------------------------------------------------------+
| PLEASE READ  THE FULL TEXT OF SOFTWARE LICENSE AGREEMENT IN THE "COPYRIGHT" |
| FILE PROVIDED WITH THIS DISTRIBUTION. THE AGREEMENT TEXT IS ALSO AVAILABLE  |
| AT THE FOLLOWING URL: https://www.x-cart.com/license-agreement-classic.html |
|                                                                             |
| THIS AGREEMENT EXPRESSES THE TERMS AND CONDITIONS ON WHICH YOU MAY USE THIS |
| SOFTWARE PROGRAM AND ASSOCIATED DOCUMENTATION THAT QUALITEAM SOFTWARE LTD   |
| (hereinafter referred to as "THE AUTHOR") OF REPUBLIC OF CYPRUS IS          |
| FURNISHING OR MAKING AVAILABLE TO YOU WITH THIS AGREEMENT (COLLECTIVELY,    |
| THE "SOFTWARE"). PLEASE REVIEW THE FOLLOWING TERMS AND CONDITIONS OF THIS   |
| LICENSE AGREEMENT CAREFULLY BEFORE INSTALLING OR USING THE SOFTWARE. BY     |
| INSTALLING, COPYING OR OTHERWISE USING THE SOFTWARE, YOU AND YOUR COMPANY   |
| (COLLECTIVELY, "YOU") ARE ACCEPTING AND AGREEING TO THE TERMS OF THIS       |
| LICENSE AGREEMENT. IF YOU ARE NOT WILLING TO BE BOUND BY THIS AGREEMENT, DO |
| NOT INSTALL OR USE THE SOFTWARE. VARIOUS COPYRIGHTS AND OTHER INTELLECTUAL  |
| PROPERTY RIGHTS PROTECT THE SOFTWARE. THIS AGREEMENT IS A LICENSE AGREEMENT |
| THAT GIVES YOU LIMITED RIGHTS TO USE THE SOFTWARE AND NOT AN AGREEMENT FOR  |
| SALE OR FOR TRANSFER OF TITLE. THE AUTHOR RETAINS ALL RIGHTS NOT EXPRESSLY  |
| GRANTED BY THIS AGREEMENT.                                                  |
+-----------------------------------------------------------------------------+
\*****************************************************************************/

/**
 * Module installation script
 *
 * @category   X-Cart
 * @package    Modules
 * @subpackage Chuck_Norris System
 * @author     Ildar Amankulov
 * @copyright  Copyright (c) 2001-present Qualiteam software Ltd <info@x-cart.com>
 * @license    https://www.x-cart.com/license-agreement-classic.html X-Cart license agreement
 * @version    $Id$
 * @link       http://www.x-cart.com/
 * @see        ____file_see____
 */

define('XCART_INSTALL', 1);
define('COMPATIBLE_VERSION', '4.7.x');

define('XMODULE_SERVICE_NAME', 'Chuck_Norris');

$module_definition = array (
    'name'       => 'Chuck_Norris system for X-Cart',
    'script'     => 'install-chuck-norris.php',
    'prefix'     => 'chuck-norris',
    'skin_files' => array (
    ),
    'successmessage' => 'func_success',
    'is_installed'   => 'func_is_installed',
    'service_name' => XMODULE_SERVICE_NAME,
    'onuninstall'    => 'func_cn_onuninstall',
);

if (!@include(dirname(__FILE__).'/top.inc.php')) {
    die('X-Cart not found in ' . dirname(__FILE__));
}

if (
    (file_exists('skin1_original') && !file_exists('skin1'))
) {
    die('You should install X-Cart first');
}

if (!file_exists('skin')) {
    die('Wrong X-Cart version');
}

if (!@include(dirname(__FILE__).'/init.php')) {
    die('init.php not found. Please, unpack ' . $module_definition['name'] . ' module in &lt;xcart&gt; directory');
}

function func_success() {
    global $xcart_package, $module_definition, $xcart_web_dir, $sql_tbl;

    if (func_is_installed()) {
    }

?>
<ol>
<li>
<a style="text-decoration: underline; font-weight: bold;" href="<?php echo $xcart_web_dir . DIR_ADMIN; ?>/configuration.php?option=<?php echo XMODULE_SERVICE_NAME;?>"><?php echo_lng('modules_admin_note'); ?></a>
</li>
</ol>
<?php
    db_query("UPDATE $sql_tbl[modules] SET active='Y' WHERE module_name='" . XMODULE_SERVICE_NAME . "'");
    func_data_cache_clear('modules');
}

function func_is_installed() {
    global $xcart_dir;

    require_once $xcart_dir . '/modules/' . XMODULE_SERVICE_NAME . '/install.php';

    return false !== func_query_first_cell("SELECT * FROM xcart_modules WHERE module_name='" . XMODULE_SERVICE_NAME . "'");
}

function func_cn_onuninstall() {
    global $sql_tbl, $sql_db;

    // Array of new columns added by the module
    // array(table_name => array(columns_names))
    $cn_columns = array(
        'memberships' => array(
            'cn_operator',
        ),
    );

    foreach ($cn_columns as $tbl => $columns) {
        if (isset($sql_tbl[$tbl])) {
            $current_columns = func_query_column("SELECT column_name FROM information_schema.columns WHERE table_schema='$sql_db' and table_name='" . $sql_tbl[$tbl] . "'");
            foreach ($columns as $column) {
                if (in_array($column, $current_columns)) {
                    db_query("ALTER TABLE " . $sql_tbl[$tbl] . " DROP COLUMN `$column`");
                }
            }
        }
    }

    return true;
}

require $xcart_dir . '/include/install.php';
